@@ -11,6 +11,10 @@ def npint32_to_buffer(data):
     return base64.b64encode(data.astype(np.int32)).decode('utf-8')
 
 
+def npuint8_to_buffer(data):
+    return base64.b64encode(data.astype(np.uint8)).decode('utf-8')
+
+
 # import
 def base64_to_type(b64data, type):
     bdata = base64.b64decode(b64data)
